# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["ObjectCreatePresignedURLParams"]


class ObjectCreatePresignedURLParams(TypedDict, total=False):
    id: Required[str]

    content_type: Annotated[str, PropertyInfo(alias="contentType")]
    """Content type for PUT operations (optional, defaults to object's content type)"""

    expires_in: Annotated[int, PropertyInfo(alias="expiresIn")]
    """URL expiration time in seconds (1 minute to 7 days)"""

    operation: Literal["GET", "PUT", "DELETE", "HEAD"]
    """The S3 operation to generate URL for"""

    size_bytes: Annotated[int, PropertyInfo(alias="sizeBytes")]
    """File size in bytes (optional, max 5GB for single PUT uploads).

    When provided for PUT operations, enforces exact file size at S3 level.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    BinaryAPIResponse,
    AsyncBinaryAPIResponse,
    StreamedBinaryAPIResponse,
    AsyncStreamedBinaryAPIResponse,
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    to_custom_raw_response_wrapper,
    async_to_streamed_response_wrapper,
    to_custom_streamed_response_wrapper,
    async_to_custom_raw_response_wrapper,
    async_to_custom_streamed_response_wrapper,
)
from ...types.vault import (
    object_delete_params,
    object_update_params,
    object_get_ocr_words_params,
    object_create_presigned_url_params,
)
from ..._base_client import make_request_options
from ...types.vault.object_list_response import ObjectListResponse
from ...types.vault.object_delete_response import ObjectDeleteResponse
from ...types.vault.object_update_response import ObjectUpdateResponse
from ...types.vault.object_get_text_response import ObjectGetTextResponse
from ...types.vault.object_retrieve_response import ObjectRetrieveResponse
from ...types.vault.object_get_ocr_words_response import ObjectGetOcrWordsResponse
from ...types.vault.object_get_summarize_job_response import ObjectGetSummarizeJobResponse
from ...types.vault.object_create_presigned_url_response import ObjectCreatePresignedURLResponse

__all__ = ["ObjectsResource", "AsyncObjectsResource"]


class ObjectsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ObjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return ObjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ObjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return ObjectsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectRetrieveResponse:
        """
        Retrieves metadata for a specific document in a vault and generates a temporary
        download URL. The download URL expires after 1 hour for security. This endpoint
        also updates the file size if it wasn't previously calculated.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._get(
            f"/vault/{id}/objects/{object_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectRetrieveResponse,
        )

    def update(
        self,
        object_id: str,
        *,
        id: str,
        filename: str | Omit = omit,
        metadata: object | Omit = omit,
        path: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectUpdateResponse:
        """Update a document's filename, path, or metadata.

        Use this to rename files or
        organize them into virtual folders. The path is stored in metadata.path and can
        be used to build folder hierarchies in your application.

        Args:
          filename: New filename for the document (affects display name and downloads)

          metadata: Additional metadata to merge with existing metadata

          path: Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). Set to
              null or empty string to remove.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._patch(
            f"/vault/{id}/objects/{object_id}",
            body=maybe_transform(
                {
                    "filename": filename,
                    "metadata": metadata,
                    "path": path,
                },
                object_update_params.ObjectUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectUpdateResponse,
        )

    def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectListResponse:
        """
        Retrieve all objects stored in a specific vault, including document metadata,
        ingestion status, and processing statistics.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/vault/{id}/objects",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectListResponse,
        )

    def delete(
        self,
        object_id: str,
        *,
        id: str,
        force: Literal["true"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectDeleteResponse:
        """
        Permanently deletes a document from the vault including all associated vectors,
        chunks, graph data, and the original file. This operation cannot be undone.

        Args:
          force: Force delete a stuck document that is still in 'processing' state. Use this if a
              document got stuck during ingestion (e.g., OCR timeout).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._delete(
            f"/vault/{id}/objects/{object_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"force": force}, object_delete_params.ObjectDeleteParams),
            ),
            cast_to=ObjectDeleteResponse,
        )

    def create_presigned_url(
        self,
        object_id: str,
        *,
        id: str,
        content_type: str | Omit = omit,
        expires_in: int | Omit = omit,
        operation: Literal["GET", "PUT", "DELETE", "HEAD"] | Omit = omit,
        size_bytes: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectCreatePresignedURLResponse:
        """
        Generate presigned URLs for direct S3 operations (GET, PUT, DELETE, HEAD) on
        vault objects. This allows secure, time-limited access to files without proxying
        through the API. Essential for large document uploads/downloads in legal
        workflows.

        Args:
          content_type: Content type for PUT operations (optional, defaults to object's content type)

          expires_in: URL expiration time in seconds (1 minute to 7 days)

          operation: The S3 operation to generate URL for

          size_bytes: File size in bytes (optional, max 5GB for single PUT uploads). When provided for
              PUT operations, enforces exact file size at S3 level.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._post(
            f"/vault/{id}/objects/{object_id}/presigned-url",
            body=maybe_transform(
                {
                    "content_type": content_type,
                    "expires_in": expires_in,
                    "operation": operation,
                    "size_bytes": size_bytes,
                },
                object_create_presigned_url_params.ObjectCreatePresignedURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectCreatePresignedURLResponse,
        )

    def download(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> BinaryAPIResponse:
        """Downloads a file from a vault.

        Returns the actual file content as a binary
        stream with appropriate headers for file download. Useful for retrieving
        contracts, depositions, case files, and other legal documents stored in your
        vault.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        extra_headers = {"Accept": "application/octet-stream", **(extra_headers or {})}
        return self._get(
            f"/vault/{id}/objects/{object_id}/download",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=BinaryAPIResponse,
        )

    def get_ocr_words(
        self,
        object_id: str,
        *,
        id: str,
        page: int | Omit = omit,
        word_end: int | Omit = omit,
        word_start: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetOcrWordsResponse:
        """Retrieves word-level OCR bounding box data for a processed PDF document.

        Each
        word includes its text, normalized bounding box coordinates (0-1 range),
        confidence score, and global word index. Use this data to highlight specific
        text ranges in a PDF viewer based on word indices from search results.

        Args:
          page: Filter to a specific page number (1-indexed). If omitted, returns all pages.

          word_end: Filter to words ending at this index (inclusive). Useful for retrieving words
              for a specific chunk.

          word_start: Filter to words starting at this index (inclusive). Useful for retrieving words
              for a specific chunk.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._get(
            f"/vault/{id}/objects/{object_id}/ocr-words",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "page": page,
                        "word_end": word_end,
                        "word_start": word_start,
                    },
                    object_get_ocr_words_params.ObjectGetOcrWordsParams,
                ),
            ),
            cast_to=ObjectGetOcrWordsResponse,
        )

    def get_summarize_job(
        self,
        job_id: str,
        *,
        id: str,
        object_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetSummarizeJobResponse:
        """
        Get the status of a CaseMark summary workflow job.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        if not job_id:
            raise ValueError(f"Expected a non-empty value for `job_id` but received {job_id!r}")
        return self._get(
            f"/vault/{id}/objects/{object_id}/summarize/{job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectGetSummarizeJobResponse,
        )

    def get_text(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetTextResponse:
        """Retrieves the full extracted text content from a processed vault object.

        Returns
        the concatenated text from all chunks, useful for document review, analysis, or
        export. The object must have completed processing before text can be retrieved.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return self._get(
            f"/vault/{id}/objects/{object_id}/text",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectGetTextResponse,
        )


class AsyncObjectsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncObjectsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncObjectsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncObjectsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncObjectsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectRetrieveResponse:
        """
        Retrieves metadata for a specific document in a vault and generates a temporary
        download URL. The download URL expires after 1 hour for security. This endpoint
        also updates the file size if it wasn't previously calculated.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._get(
            f"/vault/{id}/objects/{object_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectRetrieveResponse,
        )

    async def update(
        self,
        object_id: str,
        *,
        id: str,
        filename: str | Omit = omit,
        metadata: object | Omit = omit,
        path: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectUpdateResponse:
        """Update a document's filename, path, or metadata.

        Use this to rename files or
        organize them into virtual folders. The path is stored in metadata.path and can
        be used to build folder hierarchies in your application.

        Args:
          filename: New filename for the document (affects display name and downloads)

          metadata: Additional metadata to merge with existing metadata

          path: Folder path for hierarchy preservation (e.g., '/Discovery/Depositions'). Set to
              null or empty string to remove.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._patch(
            f"/vault/{id}/objects/{object_id}",
            body=await async_maybe_transform(
                {
                    "filename": filename,
                    "metadata": metadata,
                    "path": path,
                },
                object_update_params.ObjectUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectUpdateResponse,
        )

    async def list(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectListResponse:
        """
        Retrieve all objects stored in a specific vault, including document metadata,
        ingestion status, and processing statistics.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/vault/{id}/objects",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectListResponse,
        )

    async def delete(
        self,
        object_id: str,
        *,
        id: str,
        force: Literal["true"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectDeleteResponse:
        """
        Permanently deletes a document from the vault including all associated vectors,
        chunks, graph data, and the original file. This operation cannot be undone.

        Args:
          force: Force delete a stuck document that is still in 'processing' state. Use this if a
              document got stuck during ingestion (e.g., OCR timeout).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._delete(
            f"/vault/{id}/objects/{object_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"force": force}, object_delete_params.ObjectDeleteParams),
            ),
            cast_to=ObjectDeleteResponse,
        )

    async def create_presigned_url(
        self,
        object_id: str,
        *,
        id: str,
        content_type: str | Omit = omit,
        expires_in: int | Omit = omit,
        operation: Literal["GET", "PUT", "DELETE", "HEAD"] | Omit = omit,
        size_bytes: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectCreatePresignedURLResponse:
        """
        Generate presigned URLs for direct S3 operations (GET, PUT, DELETE, HEAD) on
        vault objects. This allows secure, time-limited access to files without proxying
        through the API. Essential for large document uploads/downloads in legal
        workflows.

        Args:
          content_type: Content type for PUT operations (optional, defaults to object's content type)

          expires_in: URL expiration time in seconds (1 minute to 7 days)

          operation: The S3 operation to generate URL for

          size_bytes: File size in bytes (optional, max 5GB for single PUT uploads). When provided for
              PUT operations, enforces exact file size at S3 level.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._post(
            f"/vault/{id}/objects/{object_id}/presigned-url",
            body=await async_maybe_transform(
                {
                    "content_type": content_type,
                    "expires_in": expires_in,
                    "operation": operation,
                    "size_bytes": size_bytes,
                },
                object_create_presigned_url_params.ObjectCreatePresignedURLParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectCreatePresignedURLResponse,
        )

    async def download(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncBinaryAPIResponse:
        """Downloads a file from a vault.

        Returns the actual file content as a binary
        stream with appropriate headers for file download. Useful for retrieving
        contracts, depositions, case files, and other legal documents stored in your
        vault.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        extra_headers = {"Accept": "application/octet-stream", **(extra_headers or {})}
        return await self._get(
            f"/vault/{id}/objects/{object_id}/download",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AsyncBinaryAPIResponse,
        )

    async def get_ocr_words(
        self,
        object_id: str,
        *,
        id: str,
        page: int | Omit = omit,
        word_end: int | Omit = omit,
        word_start: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetOcrWordsResponse:
        """Retrieves word-level OCR bounding box data for a processed PDF document.

        Each
        word includes its text, normalized bounding box coordinates (0-1 range),
        confidence score, and global word index. Use this data to highlight specific
        text ranges in a PDF viewer based on word indices from search results.

        Args:
          page: Filter to a specific page number (1-indexed). If omitted, returns all pages.

          word_end: Filter to words ending at this index (inclusive). Useful for retrieving words
              for a specific chunk.

          word_start: Filter to words starting at this index (inclusive). Useful for retrieving words
              for a specific chunk.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._get(
            f"/vault/{id}/objects/{object_id}/ocr-words",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "page": page,
                        "word_end": word_end,
                        "word_start": word_start,
                    },
                    object_get_ocr_words_params.ObjectGetOcrWordsParams,
                ),
            ),
            cast_to=ObjectGetOcrWordsResponse,
        )

    async def get_summarize_job(
        self,
        job_id: str,
        *,
        id: str,
        object_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetSummarizeJobResponse:
        """
        Get the status of a CaseMark summary workflow job.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        if not job_id:
            raise ValueError(f"Expected a non-empty value for `job_id` but received {job_id!r}")
        return await self._get(
            f"/vault/{id}/objects/{object_id}/summarize/{job_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectGetSummarizeJobResponse,
        )

    async def get_text(
        self,
        object_id: str,
        *,
        id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ObjectGetTextResponse:
        """Retrieves the full extracted text content from a processed vault object.

        Returns
        the concatenated text from all chunks, useful for document review, analysis, or
        export. The object must have completed processing before text can be retrieved.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        if not object_id:
            raise ValueError(f"Expected a non-empty value for `object_id` but received {object_id!r}")
        return await self._get(
            f"/vault/{id}/objects/{object_id}/text",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ObjectGetTextResponse,
        )


class ObjectsResourceWithRawResponse:
    def __init__(self, objects: ObjectsResource) -> None:
        self._objects = objects

        self.retrieve = to_raw_response_wrapper(
            objects.retrieve,
        )
        self.update = to_raw_response_wrapper(
            objects.update,
        )
        self.list = to_raw_response_wrapper(
            objects.list,
        )
        self.delete = to_raw_response_wrapper(
            objects.delete,
        )
        self.create_presigned_url = to_raw_response_wrapper(
            objects.create_presigned_url,
        )
        self.download = to_custom_raw_response_wrapper(
            objects.download,
            BinaryAPIResponse,
        )
        self.get_ocr_words = to_raw_response_wrapper(
            objects.get_ocr_words,
        )
        self.get_summarize_job = to_raw_response_wrapper(
            objects.get_summarize_job,
        )
        self.get_text = to_raw_response_wrapper(
            objects.get_text,
        )


class AsyncObjectsResourceWithRawResponse:
    def __init__(self, objects: AsyncObjectsResource) -> None:
        self._objects = objects

        self.retrieve = async_to_raw_response_wrapper(
            objects.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            objects.update,
        )
        self.list = async_to_raw_response_wrapper(
            objects.list,
        )
        self.delete = async_to_raw_response_wrapper(
            objects.delete,
        )
        self.create_presigned_url = async_to_raw_response_wrapper(
            objects.create_presigned_url,
        )
        self.download = async_to_custom_raw_response_wrapper(
            objects.download,
            AsyncBinaryAPIResponse,
        )
        self.get_ocr_words = async_to_raw_response_wrapper(
            objects.get_ocr_words,
        )
        self.get_summarize_job = async_to_raw_response_wrapper(
            objects.get_summarize_job,
        )
        self.get_text = async_to_raw_response_wrapper(
            objects.get_text,
        )


class ObjectsResourceWithStreamingResponse:
    def __init__(self, objects: ObjectsResource) -> None:
        self._objects = objects

        self.retrieve = to_streamed_response_wrapper(
            objects.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            objects.update,
        )
        self.list = to_streamed_response_wrapper(
            objects.list,
        )
        self.delete = to_streamed_response_wrapper(
            objects.delete,
        )
        self.create_presigned_url = to_streamed_response_wrapper(
            objects.create_presigned_url,
        )
        self.download = to_custom_streamed_response_wrapper(
            objects.download,
            StreamedBinaryAPIResponse,
        )
        self.get_ocr_words = to_streamed_response_wrapper(
            objects.get_ocr_words,
        )
        self.get_summarize_job = to_streamed_response_wrapper(
            objects.get_summarize_job,
        )
        self.get_text = to_streamed_response_wrapper(
            objects.get_text,
        )


class AsyncObjectsResourceWithStreamingResponse:
    def __init__(self, objects: AsyncObjectsResource) -> None:
        self._objects = objects

        self.retrieve = async_to_streamed_response_wrapper(
            objects.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            objects.update,
        )
        self.list = async_to_streamed_response_wrapper(
            objects.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            objects.delete,
        )
        self.create_presigned_url = async_to_streamed_response_wrapper(
            objects.create_presigned_url,
        )
        self.download = async_to_custom_streamed_response_wrapper(
            objects.download,
            AsyncStreamedBinaryAPIResponse,
        )
        self.get_ocr_words = async_to_streamed_response_wrapper(
            objects.get_ocr_words,
        )
        self.get_summarize_job = async_to_streamed_response_wrapper(
            objects.get_summarize_job,
        )
        self.get_text = async_to_streamed_response_wrapper(
            objects.get_text,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal, Required, TypedDict

__all__ = ["ChatCreateCompletionParams", "Message"]


class ChatCreateCompletionParams(TypedDict, total=False):
    messages: Required[Iterable[Message]]
    """List of messages comprising the conversation"""

    casemark_show_reasoning: bool
    """CaseMark-only: when true, allows reasoning fields in responses.

    Defaults to false (reasoning is suppressed).
    """

    frequency_penalty: float
    """Frequency penalty parameter"""

    max_tokens: int
    """Maximum number of tokens to generate"""

    model: str
    """Model to use for completion.

    Defaults to casemark/casemark-core-3 if not specified
    """

    presence_penalty: float
    """Presence penalty parameter"""

    stream: bool
    """Whether to stream back partial progress"""

    temperature: float
    """Sampling temperature between 0 and 2"""

    top_p: float
    """Nucleus sampling parameter"""


class Message(TypedDict, total=False):
    content: str
    """The contents of the message"""

    role: Literal["system", "user", "assistant"]
    """The role of the message author"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.translate import v1_detect_params, v1_translate_params, v1_list_languages_params
from ...types.translate.v1_detect_response import V1DetectResponse
from ...types.translate.v1_translate_response import V1TranslateResponse
from ...types.translate.v1_list_languages_response import V1ListLanguagesResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def detect(
        self,
        *,
        q: Union[str, SequenceNotStr[str]],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1DetectResponse:
        """Detect the language of text.

        Returns the most likely language code and
        confidence score. Supports batch detection for multiple texts.

        Args:
          q: Text to detect language for. Can be a single string or an array for batch
              detection.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/translate/v1/detect",
            body=maybe_transform({"q": q}, v1_detect_params.V1DetectParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1DetectResponse,
        )

    def list_languages(
        self,
        *,
        model: Literal["nmt", "base"] | Omit = omit,
        target: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ListLanguagesResponse:
        """Get the list of languages supported for translation.

        Optionally specify a target
        language to get translated language names.

        Args:
          model: Translation model to check language support for

          target: Target language code for translating language names (e.g., 'es' for Spanish
              names)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/translate/v1/languages",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "model": model,
                        "target": target,
                    },
                    v1_list_languages_params.V1ListLanguagesParams,
                ),
            ),
            cast_to=V1ListLanguagesResponse,
        )

    def translate(
        self,
        *,
        q: Union[str, SequenceNotStr[str]],
        target: str,
        format: Literal["text", "html"] | Omit = omit,
        model: Literal["nmt", "base"] | Omit = omit,
        source: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1TranslateResponse:
        """Translate text between languages using Google Cloud Translation API.

        Supports
        100+ languages, automatic language detection, HTML preservation, and batch
        translation.

        Args:
          q: Text to translate. Can be a single string or an array for batch translation.

          target: Target language code (ISO 639-1)

          format: Format of the source text. Use 'html' to preserve HTML tags.

          model: Translation model. 'nmt' (Neural Machine Translation) is recommended for
              quality.

          source: Source language code (ISO 639-1). If not specified, language is auto-detected.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/translate/v1/translate",
            body=maybe_transform(
                {
                    "q": q,
                    "target": target,
                    "format": format,
                    "model": model,
                    "source": source,
                },
                v1_translate_params.V1TranslateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1TranslateResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def detect(
        self,
        *,
        q: Union[str, SequenceNotStr[str]],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1DetectResponse:
        """Detect the language of text.

        Returns the most likely language code and
        confidence score. Supports batch detection for multiple texts.

        Args:
          q: Text to detect language for. Can be a single string or an array for batch
              detection.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/translate/v1/detect",
            body=await async_maybe_transform({"q": q}, v1_detect_params.V1DetectParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1DetectResponse,
        )

    async def list_languages(
        self,
        *,
        model: Literal["nmt", "base"] | Omit = omit,
        target: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1ListLanguagesResponse:
        """Get the list of languages supported for translation.

        Optionally specify a target
        language to get translated language names.

        Args:
          model: Translation model to check language support for

          target: Target language code for translating language names (e.g., 'es' for Spanish
              names)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/translate/v1/languages",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "model": model,
                        "target": target,
                    },
                    v1_list_languages_params.V1ListLanguagesParams,
                ),
            ),
            cast_to=V1ListLanguagesResponse,
        )

    async def translate(
        self,
        *,
        q: Union[str, SequenceNotStr[str]],
        target: str,
        format: Literal["text", "html"] | Omit = omit,
        model: Literal["nmt", "base"] | Omit = omit,
        source: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1TranslateResponse:
        """Translate text between languages using Google Cloud Translation API.

        Supports
        100+ languages, automatic language detection, HTML preservation, and batch
        translation.

        Args:
          q: Text to translate. Can be a single string or an array for batch translation.

          target: Target language code (ISO 639-1)

          format: Format of the source text. Use 'html' to preserve HTML tags.

          model: Translation model. 'nmt' (Neural Machine Translation) is recommended for
              quality.

          source: Source language code (ISO 639-1). If not specified, language is auto-detected.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/translate/v1/translate",
            body=await async_maybe_transform(
                {
                    "q": q,
                    "target": target,
                    "format": format,
                    "model": model,
                    "source": source,
                },
                v1_translate_params.V1TranslateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1TranslateResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.detect = to_raw_response_wrapper(
            v1.detect,
        )
        self.list_languages = to_raw_response_wrapper(
            v1.list_languages,
        )
        self.translate = to_raw_response_wrapper(
            v1.translate,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.detect = async_to_raw_response_wrapper(
            v1.detect,
        )
        self.list_languages = async_to_raw_response_wrapper(
            v1.list_languages,
        )
        self.translate = async_to_raw_response_wrapper(
            v1.translate,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.detect = to_streamed_response_wrapper(
            v1.detect,
        )
        self.list_languages = to_streamed_response_wrapper(
            v1.list_languages,
        )
        self.translate = to_streamed_response_wrapper(
            v1.translate,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.detect = async_to_streamed_response_wrapper(
            v1.detect,
        )
        self.list_languages = async_to_streamed_response_wrapper(
            v1.list_languages,
        )
        self.translate = async_to_streamed_response_wrapper(
            v1.translate,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .vault_create_params import VaultCreateParams as VaultCreateParams
from .vault_delete_params import VaultDeleteParams as VaultDeleteParams
from .vault_list_response import VaultListResponse as VaultListResponse
from .vault_search_params import VaultSearchParams as VaultSearchParams
from .vault_update_params import VaultUpdateParams as VaultUpdateParams
from .vault_upload_params import VaultUploadParams as VaultUploadParams
from .vault_create_response import VaultCreateResponse as VaultCreateResponse
from .vault_delete_response import VaultDeleteResponse as VaultDeleteResponse
from .vault_ingest_response import VaultIngestResponse as VaultIngestResponse
from .vault_search_response import VaultSearchResponse as VaultSearchResponse
from .vault_update_response import VaultUpdateResponse as VaultUpdateResponse
from .vault_upload_response import VaultUploadResponse as VaultUploadResponse
from .llm_get_config_response import LlmGetConfigResponse as LlmGetConfigResponse
from .vault_retrieve_response import VaultRetrieveResponse as VaultRetrieveResponse
from .vault_confirm_upload_params import VaultConfirmUploadParams as VaultConfirmUploadParams
from .system_list_services_response import SystemListServicesResponse as SystemListServicesResponse
from .vault_confirm_upload_response import VaultConfirmUploadResponse as VaultConfirmUploadResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["V1ContentsParams"]


class V1ContentsParams(TypedDict, total=False):
    urls: Required[SequenceNotStr[str]]
    """Array of URLs to scrape and extract content from"""

    context: str
    """Context to guide content extraction and summarization"""

    extras: object
    """Additional extraction options"""

    highlights: bool
    """Whether to include content highlights"""

    livecrawl: bool
    """Whether to perform live crawling for dynamic content"""

    livecrawl_timeout: Annotated[int, PropertyInfo(alias="livecrawlTimeout")]
    """Timeout in seconds for live crawling"""

    subpages: bool
    """Whether to extract content from linked subpages"""

    subpage_target: Annotated[int, PropertyInfo(alias="subpageTarget")]
    """Maximum number of subpages to crawl"""

    summary: bool
    """Whether to generate content summaries"""

    text: bool
    """Whether to extract text content"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

from ...._types import SequenceNotStr

__all__ = ["TemplateCreateParams"]


class TemplateCreateParams(TypedDict, total=False):
    content: Required[str]
    """Template content with {{variable}} placeholders"""

    name: Required[str]
    """Template name"""

    type: Required[Literal["caption", "signature", "letterhead", "certificate", "footer", "custom"]]
    """Template type"""

    description: str
    """Template description"""

    styles: object
    """CSS styles for the template"""

    tags: SequenceNotStr[str]
    """Template tags for organization"""

    variables: SequenceNotStr[str]
    """Template variables (auto-detected if not provided)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from ..._models import BaseModel

__all__ = ["V1ListJurisdictionsResponse", "Jurisdiction"]


class Jurisdiction(BaseModel):
    id: Optional[str] = None
    """Jurisdiction ID to use in other endpoints"""

    level: Optional[Literal["federal", "state", "county", "municipal"]] = None
    """Jurisdiction level"""

    name: Optional[str] = None
    """Full jurisdiction name"""

    state: Optional[str] = None
    """State abbreviation (if applicable)"""


class V1ListJurisdictionsResponse(BaseModel):
    found: Optional[int] = None
    """Number of matching jurisdictions"""

    hint: Optional[str] = None
    """Usage guidance"""

    jurisdictions: Optional[List[Jurisdiction]] = None

    query: Optional[str] = None
    """Original search query"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from casedev import Casedev, AsyncCasedev
from tests.utils import assert_matches_type
from casedev.types.applications.v1 import (
    ProjectListResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProjects:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_create(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create(
            git_repo="gitRepo",
            name="name",
        )
        assert project is None

    @parametrize
    def test_method_create_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create(
            git_repo="gitRepo",
            name="name",
            build_command="buildCommand",
            environment_variables=[
                {
                    "key": "key",
                    "target": ["production"],
                    "value": "value",
                    "type": "plain",
                }
            ],
            framework="framework",
            git_branch="gitBranch",
            install_command="installCommand",
            output_directory="outputDirectory",
            root_directory="rootDirectory",
        )
        assert project is None

    @parametrize
    def test_raw_response_create(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.create(
            git_repo="gitRepo",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_create(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.create(
            git_repo="gitRepo",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_retrieve(self, client: Casedev) -> None:
        project = client.applications.v1.projects.retrieve(
            "id",
        )
        assert project is None

    @parametrize
    def test_raw_response_retrieve(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_retrieve(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.retrieve(
                "",
            )

    @parametrize
    def test_method_list(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert_matches_type(ProjectListResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_delete(self, client: Casedev) -> None:
        project = client.applications.v1.projects.delete(
            id="id",
        )
        assert project is None

    @parametrize
    def test_method_delete_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.delete(
            id="id",
            delete_from_hosting=True,
        )
        assert project is None

    @parametrize
    def test_raw_response_delete(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.delete(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_delete(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.delete(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.delete(
                id="",
            )

    @parametrize
    def test_method_create_deployment(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_deployment(
            id="id",
        )
        assert project is None

    @parametrize
    def test_method_create_deployment_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_deployment(
            id="id",
            environment_variables=[
                {
                    "key": "key",
                    "target": ["production"],
                    "value": "value",
                    "type": "plain",
                }
            ],
        )
        assert project is None

    @parametrize
    def test_raw_response_create_deployment(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.create_deployment(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_create_deployment(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.create_deployment(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_deployment(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.create_deployment(
                id="",
            )

    @parametrize
    def test_method_create_domain(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_domain(
            id="id",
            domain="domain",
        )
        assert project is None

    @parametrize
    def test_method_create_domain_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_domain(
            id="id",
            domain="domain",
            git_branch="gitBranch",
        )
        assert project is None

    @parametrize
    def test_raw_response_create_domain(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.create_domain(
            id="id",
            domain="domain",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_create_domain(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.create_domain(
            id="id",
            domain="domain",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_domain(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.create_domain(
                id="",
                domain="domain",
            )

    @parametrize
    def test_method_create_env(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        )
        assert project is None

    @parametrize
    def test_method_create_env_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
            git_branch="gitBranch",
            type="plain",
        )
        assert project is None

    @parametrize
    def test_raw_response_create_env(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_create_env(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_create_env(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.create_env(
                id="",
                key="key",
                target=["production"],
                value="value",
            )

    @parametrize
    def test_method_delete_domain(self, client: Casedev) -> None:
        project = client.applications.v1.projects.delete_domain(
            domain="domain",
            id="id",
        )
        assert project is None

    @parametrize
    def test_raw_response_delete_domain(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.delete_domain(
            domain="domain",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_delete_domain(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.delete_domain(
            domain="domain",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete_domain(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.delete_domain(
                domain="domain",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `domain` but received ''"):
            client.applications.v1.projects.with_raw_response.delete_domain(
                domain="",
                id="id",
            )

    @parametrize
    def test_method_delete_env(self, client: Casedev) -> None:
        project = client.applications.v1.projects.delete_env(
            env_id="envId",
            id="id",
        )
        assert project is None

    @parametrize
    def test_raw_response_delete_env(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.delete_env(
            env_id="envId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_delete_env(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.delete_env(
            env_id="envId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_delete_env(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.delete_env(
                env_id="envId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `env_id` but received ''"):
            client.applications.v1.projects.with_raw_response.delete_env(
                env_id="",
                id="id",
            )

    @parametrize
    def test_method_get_runtime_logs(self, client: Casedev) -> None:
        project = client.applications.v1.projects.get_runtime_logs(
            id="id",
        )
        assert project is None

    @parametrize
    def test_method_get_runtime_logs_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.get_runtime_logs(
            id="id",
            limit=0,
        )
        assert project is None

    @parametrize
    def test_raw_response_get_runtime_logs(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.get_runtime_logs(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_get_runtime_logs(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.get_runtime_logs(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_get_runtime_logs(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.get_runtime_logs(
                id="",
            )

    @parametrize
    def test_method_list_deployments(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list_deployments(
            id="id",
        )
        assert project is None

    @parametrize
    def test_method_list_deployments_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list_deployments(
            id="id",
            limit=0,
            state="state",
            target="production",
        )
        assert project is None

    @parametrize
    def test_raw_response_list_deployments(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.list_deployments(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_list_deployments(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.list_deployments(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_deployments(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.list_deployments(
                id="",
            )

    @parametrize
    def test_method_list_domains(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list_domains(
            "id",
        )
        assert project is None

    @parametrize
    def test_raw_response_list_domains(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.list_domains(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_list_domains(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.list_domains(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_domains(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.list_domains(
                "",
            )

    @parametrize
    def test_method_list_env(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list_env(
            id="id",
        )
        assert project is None

    @parametrize
    def test_method_list_env_with_all_params(self, client: Casedev) -> None:
        project = client.applications.v1.projects.list_env(
            id="id",
            decrypt=True,
        )
        assert project is None

    @parametrize
    def test_raw_response_list_env(self, client: Casedev) -> None:
        response = client.applications.v1.projects.with_raw_response.list_env(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = response.parse()
        assert project is None

    @parametrize
    def test_streaming_response_list_env(self, client: Casedev) -> None:
        with client.applications.v1.projects.with_streaming_response.list_env(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list_env(self, client: Casedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.applications.v1.projects.with_raw_response.list_env(
                id="",
            )


class TestAsyncProjects:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @parametrize
    async def test_method_create(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create(
            git_repo="gitRepo",
            name="name",
        )
        assert project is None

    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create(
            git_repo="gitRepo",
            name="name",
            build_command="buildCommand",
            environment_variables=[
                {
                    "key": "key",
                    "target": ["production"],
                    "value": "value",
                    "type": "plain",
                }
            ],
            framework="framework",
            git_branch="gitBranch",
            install_command="installCommand",
            output_directory="outputDirectory",
            root_directory="rootDirectory",
        )
        assert project is None

    @parametrize
    async def test_raw_response_create(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.create(
            git_repo="gitRepo",
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.create(
            git_repo="gitRepo",
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.retrieve(
            "id",
        )
        assert project is None

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.retrieve(
                "",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert_matches_type(ProjectListResponse, project, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert_matches_type(ProjectListResponse, project, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_delete(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.delete(
            id="id",
        )
        assert project is None

    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.delete(
            id="id",
            delete_from_hosting=True,
        )
        assert project is None

    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.delete(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.delete(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.delete(
                id="",
            )

    @parametrize
    async def test_method_create_deployment(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_deployment(
            id="id",
        )
        assert project is None

    @parametrize
    async def test_method_create_deployment_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_deployment(
            id="id",
            environment_variables=[
                {
                    "key": "key",
                    "target": ["production"],
                    "value": "value",
                    "type": "plain",
                }
            ],
        )
        assert project is None

    @parametrize
    async def test_raw_response_create_deployment(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.create_deployment(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_create_deployment(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.create_deployment(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_deployment(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.create_deployment(
                id="",
            )

    @parametrize
    async def test_method_create_domain(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_domain(
            id="id",
            domain="domain",
        )
        assert project is None

    @parametrize
    async def test_method_create_domain_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_domain(
            id="id",
            domain="domain",
            git_branch="gitBranch",
        )
        assert project is None

    @parametrize
    async def test_raw_response_create_domain(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.create_domain(
            id="id",
            domain="domain",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_create_domain(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.create_domain(
            id="id",
            domain="domain",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_domain(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.create_domain(
                id="",
                domain="domain",
            )

    @parametrize
    async def test_method_create_env(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        )
        assert project is None

    @parametrize
    async def test_method_create_env_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
            git_branch="gitBranch",
            type="plain",
        )
        assert project is None

    @parametrize
    async def test_raw_response_create_env(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_create_env(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.create_env(
            id="id",
            key="key",
            target=["production"],
            value="value",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_create_env(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.create_env(
                id="",
                key="key",
                target=["production"],
                value="value",
            )

    @parametrize
    async def test_method_delete_domain(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.delete_domain(
            domain="domain",
            id="id",
        )
        assert project is None

    @parametrize
    async def test_raw_response_delete_domain(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.delete_domain(
            domain="domain",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_delete_domain(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.delete_domain(
            domain="domain",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete_domain(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.delete_domain(
                domain="domain",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `domain` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.delete_domain(
                domain="",
                id="id",
            )

    @parametrize
    async def test_method_delete_env(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.delete_env(
            env_id="envId",
            id="id",
        )
        assert project is None

    @parametrize
    async def test_raw_response_delete_env(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.delete_env(
            env_id="envId",
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_delete_env(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.delete_env(
            env_id="envId",
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_delete_env(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.delete_env(
                env_id="envId",
                id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `env_id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.delete_env(
                env_id="",
                id="id",
            )

    @parametrize
    async def test_method_get_runtime_logs(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.get_runtime_logs(
            id="id",
        )
        assert project is None

    @parametrize
    async def test_method_get_runtime_logs_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.get_runtime_logs(
            id="id",
            limit=0,
        )
        assert project is None

    @parametrize
    async def test_raw_response_get_runtime_logs(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.get_runtime_logs(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_get_runtime_logs(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.get_runtime_logs(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_get_runtime_logs(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.get_runtime_logs(
                id="",
            )

    @parametrize
    async def test_method_list_deployments(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list_deployments(
            id="id",
        )
        assert project is None

    @parametrize
    async def test_method_list_deployments_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list_deployments(
            id="id",
            limit=0,
            state="state",
            target="production",
        )
        assert project is None

    @parametrize
    async def test_raw_response_list_deployments(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.list_deployments(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_list_deployments(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.list_deployments(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_deployments(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.list_deployments(
                id="",
            )

    @parametrize
    async def test_method_list_domains(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list_domains(
            "id",
        )
        assert project is None

    @parametrize
    async def test_raw_response_list_domains(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.list_domains(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_list_domains(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.list_domains(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_domains(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.list_domains(
                "",
            )

    @parametrize
    async def test_method_list_env(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list_env(
            id="id",
        )
        assert project is None

    @parametrize
    async def test_method_list_env_with_all_params(self, async_client: AsyncCasedev) -> None:
        project = await async_client.applications.v1.projects.list_env(
            id="id",
            decrypt=True,
        )
        assert project is None

    @parametrize
    async def test_raw_response_list_env(self, async_client: AsyncCasedev) -> None:
        response = await async_client.applications.v1.projects.with_raw_response.list_env(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        project = await response.parse()
        assert project is None

    @parametrize
    async def test_streaming_response_list_env(self, async_client: AsyncCasedev) -> None:
        async with async_client.applications.v1.projects.with_streaming_response.list_env(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            project = await response.parse()
            assert project is None

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list_env(self, async_client: AsyncCasedev) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.applications.v1.projects.with_raw_response.list_env(
                id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = ["AgentCreateParams", "Sandbox"]


class AgentCreateParams(TypedDict, total=False):
    instructions: Required[str]
    """System instructions that define agent behavior"""

    name: Required[str]
    """Display name for the agent"""

    description: str
    """Optional description of the agent"""

    disabled_tools: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="disabledTools")]
    """Denylist of tools the agent cannot use"""

    enabled_tools: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="enabledTools")]
    """Allowlist of tools the agent can use"""

    model: str
    """LLM model identifier (e.g.

    anthropic/claude-sonnet-4.6). Defaults to anthropic/claude-sonnet-4.6
    """

    sandbox: Optional[Sandbox]
    """Custom sandbox configuration (cpu, memoryMiB)"""

    vault_groups: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="vaultGroups")]
    """Restrict agent to vaults within specific vault group IDs"""

    vault_ids: Annotated[Optional[SequenceNotStr[str]], PropertyInfo(alias="vaultIds")]
    """Restrict agent to specific vault IDs"""


class Sandbox(TypedDict, total=False):
    """Custom sandbox configuration (cpu, memoryMiB)"""

    cpu: int
    """Number of CPUs"""

    memory_mi_b: Annotated[int, PropertyInfo(alias="memoryMiB")]
    """Memory in MiB"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["DeploymentListParams"]


class DeploymentListParams(TypedDict, total=False):
    project_id: Required[Annotated[str, PropertyInfo(alias="projectId")]]
    """Project ID"""

    limit: float
    """Maximum number of deployments to return"""

    state: str
    """Filter by deployment state"""

    target: Literal["production", "staging"]
    """Filter by deployment target"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.applications.v1 import workflow_get_status_params

__all__ = ["WorkflowsResource", "AsyncWorkflowsResource"]


class WorkflowsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> WorkflowsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return WorkflowsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WorkflowsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return WorkflowsResourceWithStreamingResponse(self)

    def get_status(
        self,
        id: str,
        *,
        project_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get current deployment workflow status and accumulated events

        Args:
          project_id: Project ID (for authorization)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._get(
            f"/applications/v1/workflows/{id}/status",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"project_id": project_id}, workflow_get_status_params.WorkflowGetStatusParams),
            ),
            cast_to=NoneType,
        )


class AsyncWorkflowsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncWorkflowsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWorkflowsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWorkflowsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncWorkflowsResourceWithStreamingResponse(self)

    async def get_status(
        self,
        id: str,
        *,
        project_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Get current deployment workflow status and accumulated events

        Args:
          project_id: Project ID (for authorization)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/applications/v1/workflows/{id}/status",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"project_id": project_id}, workflow_get_status_params.WorkflowGetStatusParams
                ),
            ),
            cast_to=NoneType,
        )


class WorkflowsResourceWithRawResponse:
    def __init__(self, workflows: WorkflowsResource) -> None:
        self._workflows = workflows

        self.get_status = to_raw_response_wrapper(
            workflows.get_status,
        )


class AsyncWorkflowsResourceWithRawResponse:
    def __init__(self, workflows: AsyncWorkflowsResource) -> None:
        self._workflows = workflows

        self.get_status = async_to_raw_response_wrapper(
            workflows.get_status,
        )


class WorkflowsResourceWithStreamingResponse:
    def __init__(self, workflows: WorkflowsResource) -> None:
        self._workflows = workflows

        self.get_status = to_streamed_response_wrapper(
            workflows.get_status,
        )


class AsyncWorkflowsResourceWithStreamingResponse:
    def __init__(self, workflows: AsyncWorkflowsResource) -> None:
        self._workflows = workflows

        self.get_status = async_to_streamed_response_wrapper(
            workflows.get_status,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["MultipartAbortParams"]


class MultipartAbortParams(TypedDict, total=False):
    object_id: Required[Annotated[str, PropertyInfo(alias="objectId")]]

    upload_id: Required[Annotated[str, PropertyInfo(alias="uploadId")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1RetrieveResearchResponse", "Results", "ResultsSection", "ResultsSectionSource", "ResultsSource"]


class ResultsSectionSource(BaseModel):
    snippet: Optional[str] = None

    title: Optional[str] = None

    url: Optional[str] = None


class ResultsSection(BaseModel):
    content: Optional[str] = None

    sources: Optional[List[ResultsSectionSource]] = None

    title: Optional[str] = None


class ResultsSource(BaseModel):
    snippet: Optional[str] = None

    title: Optional[str] = None

    url: Optional[str] = None


class Results(BaseModel):
    """Research findings and analysis"""

    sections: Optional[List[ResultsSection]] = None
    """Detailed research sections"""

    sources: Optional[List[ResultsSource]] = None
    """All sources referenced in research"""

    summary: Optional[str] = None
    """Executive summary of research findings"""


class V1RetrieveResearchResponse(BaseModel):
    id: Optional[str] = None
    """Research task ID"""

    completed_at: Optional[datetime] = FieldInfo(alias="completedAt", default=None)
    """Task completion timestamp"""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Task creation timestamp"""

    model: Optional[Literal["fast", "normal", "pro"]] = None
    """Research model used"""

    progress: Optional[float] = None
    """Completion percentage (0-100)"""

    query: Optional[str] = None
    """Original research query"""

    results: Optional[Results] = None
    """Research findings and analysis"""

    status: Optional[Literal["pending", "running", "completed", "failed"]] = None
    """Current status of the research task"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["V1VerifyParams"]


class V1VerifyParams(TypedDict, total=False):
    text: Required[str]
    """Text containing citations to verify.

    Can be a single citation (e.g., "531 U.S. 98") or a full document with multiple
    citations.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1TranslateResponse", "Data", "DataTranslation"]


class DataTranslation(BaseModel):
    detected_source_language: Optional[str] = FieldInfo(alias="detectedSourceLanguage", default=None)
    """Detected source language (if source not specified)"""

    model: Optional[str] = None
    """Model used for translation"""

    translated_text: Optional[str] = FieldInfo(alias="translatedText", default=None)
    """Translated text"""


class Data(BaseModel):
    translations: Optional[List[DataTranslation]] = None


class V1TranslateResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ..._models import BaseModel

__all__ = ["V1ListLanguagesResponse", "Data", "DataLanguage"]


class DataLanguage(BaseModel):
    language: Optional[str] = None
    """Language code (ISO 639-1)"""

    name: Optional[str] = None
    """Language name (if target specified)"""


class Data(BaseModel):
    languages: Optional[List[DataLanguage]] = None


class V1ListLanguagesResponse(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal, Required, Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ProjectCreateParams", "EnvironmentVariable"]


class ProjectCreateParams(TypedDict, total=False):
    git_repo: Required[Annotated[str, PropertyInfo(alias="gitRepo")]]
    """GitHub repository URL or "owner/repo" """

    name: Required[str]
    """Project name"""

    build_command: Annotated[str, PropertyInfo(alias="buildCommand")]
    """Custom build command"""

    environment_variables: Annotated[Iterable[EnvironmentVariable], PropertyInfo(alias="environmentVariables")]
    """Environment variables to set on the project"""

    framework: str
    """Framework (e.g., "nextjs", "remix", "astro")"""

    git_branch: Annotated[str, PropertyInfo(alias="gitBranch")]
    """Git branch to deploy"""

    install_command: Annotated[str, PropertyInfo(alias="installCommand")]
    """Custom install command"""

    output_directory: Annotated[str, PropertyInfo(alias="outputDirectory")]
    """Build output directory"""

    root_directory: Annotated[str, PropertyInfo(alias="rootDirectory")]
    """Root directory of the project"""


class EnvironmentVariable(TypedDict, total=False):
    key: Required[str]
    """Environment variable name"""

    target: Required[List[Literal["production", "preview", "development"]]]
    """Deployment targets for this variable"""

    value: Required[str]
    """Environment variable value"""

    type: Literal["plain", "encrypted", "secret"]
    """Variable type"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.compute.v1 import environment_create_params
from ....types.compute.v1.environment_list_response import EnvironmentListResponse
from ....types.compute.v1.environment_create_response import EnvironmentCreateResponse
from ....types.compute.v1.environment_delete_response import EnvironmentDeleteResponse
from ....types.compute.v1.environment_retrieve_response import EnvironmentRetrieveResponse
from ....types.compute.v1.environment_set_default_response import EnvironmentSetDefaultResponse

__all__ = ["EnvironmentsResource", "AsyncEnvironmentsResource"]


class EnvironmentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EnvironmentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return EnvironmentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EnvironmentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return EnvironmentsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentCreateResponse:
        """Creates a new compute environment for running serverless workloads.

        Each
        environment gets its own isolated namespace with a unique domain for hosting
        applications and APIs. The first environment created becomes the default
        environment for the organization.

        Args:
          name: Environment name (alphanumeric, hyphens, and underscores only)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/compute/v1/environments",
            body=maybe_transform({"name": name}, environment_create_params.EnvironmentCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentCreateResponse,
        )

    def retrieve(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentRetrieveResponse:
        """Retrieve a specific compute environment by name.

        Returns environment
        configuration including status, domain, and metadata for your serverless compute
        infrastructure.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return self._get(
            f"/compute/v1/environments/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentRetrieveResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentListResponse:
        """Retrieve all compute environments for your organization.

        Environments provide
        isolated execution contexts for running code and workflows.
        """
        return self._get(
            "/compute/v1/environments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentListResponse,
        )

    def delete(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentDeleteResponse:
        """Permanently delete a compute environment and all its associated resources.

        This
        will stop all running deployments and clean up related configurations. The
        default environment cannot be deleted if other environments exist.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return self._delete(
            f"/compute/v1/environments/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentDeleteResponse,
        )

    def set_default(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentSetDefaultResponse:
        """Sets a compute environment as the default for the organization.

        Only one
        environment can be default at a time - setting a new default will automatically
        unset the previous one.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return self._post(
            f"/compute/v1/environments/{name}/default",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentSetDefaultResponse,
        )


class AsyncEnvironmentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEnvironmentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEnvironmentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEnvironmentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncEnvironmentsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentCreateResponse:
        """Creates a new compute environment for running serverless workloads.

        Each
        environment gets its own isolated namespace with a unique domain for hosting
        applications and APIs. The first environment created becomes the default
        environment for the organization.

        Args:
          name: Environment name (alphanumeric, hyphens, and underscores only)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/compute/v1/environments",
            body=await async_maybe_transform({"name": name}, environment_create_params.EnvironmentCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentCreateResponse,
        )

    async def retrieve(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentRetrieveResponse:
        """Retrieve a specific compute environment by name.

        Returns environment
        configuration including status, domain, and metadata for your serverless compute
        infrastructure.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return await self._get(
            f"/compute/v1/environments/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentRetrieveResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentListResponse:
        """Retrieve all compute environments for your organization.

        Environments provide
        isolated execution contexts for running code and workflows.
        """
        return await self._get(
            "/compute/v1/environments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentListResponse,
        )

    async def delete(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentDeleteResponse:
        """Permanently delete a compute environment and all its associated resources.

        This
        will stop all running deployments and clean up related configurations. The
        default environment cannot be deleted if other environments exist.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return await self._delete(
            f"/compute/v1/environments/{name}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentDeleteResponse,
        )

    async def set_default(
        self,
        name: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> EnvironmentSetDefaultResponse:
        """Sets a compute environment as the default for the organization.

        Only one
        environment can be default at a time - setting a new default will automatically
        unset the previous one.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not name:
            raise ValueError(f"Expected a non-empty value for `name` but received {name!r}")
        return await self._post(
            f"/compute/v1/environments/{name}/default",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=EnvironmentSetDefaultResponse,
        )


class EnvironmentsResourceWithRawResponse:
    def __init__(self, environments: EnvironmentsResource) -> None:
        self._environments = environments

        self.create = to_raw_response_wrapper(
            environments.create,
        )
        self.retrieve = to_raw_response_wrapper(
            environments.retrieve,
        )
        self.list = to_raw_response_wrapper(
            environments.list,
        )
        self.delete = to_raw_response_wrapper(
            environments.delete,
        )
        self.set_default = to_raw_response_wrapper(
            environments.set_default,
        )


class AsyncEnvironmentsResourceWithRawResponse:
    def __init__(self, environments: AsyncEnvironmentsResource) -> None:
        self._environments = environments

        self.create = async_to_raw_response_wrapper(
            environments.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            environments.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            environments.list,
        )
        self.delete = async_to_raw_response_wrapper(
            environments.delete,
        )
        self.set_default = async_to_raw_response_wrapper(
            environments.set_default,
        )


class EnvironmentsResourceWithStreamingResponse:
    def __init__(self, environments: EnvironmentsResource) -> None:
        self._environments = environments

        self.create = to_streamed_response_wrapper(
            environments.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            environments.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            environments.list,
        )
        self.delete = to_streamed_response_wrapper(
            environments.delete,
        )
        self.set_default = to_streamed_response_wrapper(
            environments.set_default,
        )


class AsyncEnvironmentsResourceWithStreamingResponse:
    def __init__(self, environments: AsyncEnvironmentsResource) -> None:
        self._environments = environments

        self.create = async_to_streamed_response_wrapper(
            environments.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            environments.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            environments.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            environments.delete,
        )
        self.set_default = async_to_streamed_response_wrapper(
            environments.set_default,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["ProjectListResponse", "Project", "ProjectDomain"]


class ProjectDomain(BaseModel):
    id: Optional[str] = None

    domain: Optional[str] = None

    is_primary: Optional[bool] = FieldInfo(alias="isPrimary", default=None)

    is_verified: Optional[bool] = FieldInfo(alias="isVerified", default=None)


class Project(BaseModel):
    id: Optional[str] = None

    created_at: Optional[str] = FieldInfo(alias="createdAt", default=None)

    domains: Optional[List[ProjectDomain]] = None

    framework: Optional[str] = None

    git_branch: Optional[str] = FieldInfo(alias="gitBranch", default=None)

    git_repo: Optional[str] = FieldInfo(alias="gitRepo", default=None)

    name: Optional[str] = None

    status: Optional[str] = None

    updated_at: Optional[str] = FieldInfo(alias="updatedAt", default=None)

    vercel_project_id: Optional[str] = FieldInfo(alias="vercelProjectId", default=None)


class ProjectListResponse(BaseModel):
    projects: Optional[List[Project]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_convert_params import V1ConvertParams as V1ConvertParams
from .v1_annotate_params import V1AnnotateParams as V1AnnotateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from datetime import date
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1PatentSearchParams"]


class V1PatentSearchParams(TypedDict, total=False):
    query: Required[str]
    """Free-text search across all patent fields, or field-specific query (e.g.

    "applicationMetaData.patentNumber:11234567"). Supports AND, OR, NOT operators.
    """

    application_status: Annotated[str, PropertyInfo(alias="applicationStatus")]
    """Filter by application status (e.g. "Patented Case", "Abandoned", "Pending")"""

    application_type: Annotated[
        Literal["Utility", "Design", "Plant", "Provisional", "Reissue"], PropertyInfo(alias="applicationType")
    ]
    """Filter by application type"""

    assignee: str
    """Filter by assignee/owner name (e.g. "Google LLC")"""

    filing_date_from: Annotated[Union[str, date], PropertyInfo(alias="filingDateFrom", format="iso8601")]
    """Start of filing date range (YYYY-MM-DD)"""

    filing_date_to: Annotated[Union[str, date], PropertyInfo(alias="filingDateTo", format="iso8601")]
    """End of filing date range (YYYY-MM-DD)"""

    grant_date_from: Annotated[Union[str, date], PropertyInfo(alias="grantDateFrom", format="iso8601")]
    """Start of grant date range (YYYY-MM-DD)"""

    grant_date_to: Annotated[Union[str, date], PropertyInfo(alias="grantDateTo", format="iso8601")]
    """End of grant date range (YYYY-MM-DD)"""

    inventor: str
    """Filter by inventor name"""

    limit: int
    """Number of results to return (default 25, max 100)"""

    offset: int
    """Starting position for pagination"""

    sort_by: Annotated[Literal["filingDate", "grantDate"], PropertyInfo(alias="sortBy")]
    """Field to sort results by"""

    sort_order: Annotated[Literal["asc", "desc"], PropertyInfo(alias="sortOrder")]
    """Sort order (default desc, newest first)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.format.v1 import template_list_params, template_create_params
from ....types.format.v1.template_list_response import TemplateListResponse
from ....types.format.v1.template_create_response import TemplateCreateResponse
from ....types.format.v1.template_retrieve_response import TemplateRetrieveResponse

__all__ = ["TemplatesResource", "AsyncTemplatesResource"]


class TemplatesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TemplatesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return TemplatesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TemplatesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return TemplatesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        content: str,
        name: str,
        type: Literal["caption", "signature", "letterhead", "certificate", "footer", "custom"],
        description: str | Omit = omit,
        styles: object | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        variables: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateCreateResponse:
        """Create a new format template for document formatting.

        Templates support
        variables using `{{variable}}` syntax and can be used for captions, signatures,
        letterheads, certificates, footers, or custom formatting needs.

        Args:
          content: Template content with {{variable}} placeholders

          name: Template name

          type: Template type

          description: Template description

          styles: CSS styles for the template

          tags: Template tags for organization

          variables: Template variables (auto-detected if not provided)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/format/v1/templates",
            body=maybe_transform(
                {
                    "content": content,
                    "name": name,
                    "type": type,
                    "description": description,
                    "styles": styles,
                    "tags": tags,
                    "variables": variables,
                },
                template_create_params.TemplateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateCreateResponse,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateRetrieveResponse:
        """Retrieve a specific document format template by ID.

        Format templates define how
        documents should be structured and formatted for specific legal use cases such
        as contracts, briefs, or pleadings.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._get(
            f"/format/v1/templates/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateRetrieveResponse,
        )

    def list(
        self,
        *,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateListResponse:
        """Retrieve all format templates for the organization.

        Templates define reusable
        document formatting patterns with customizable variables for consistent legal
        document generation.

        Filter by type to get specific template categories like contracts, pleadings, or
        correspondence.

        Args:
          type: Filter templates by type (e.g., contract, pleading, letter)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/format/v1/templates",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"type": type}, template_list_params.TemplateListParams),
            ),
            cast_to=TemplateListResponse,
        )


class AsyncTemplatesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTemplatesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/CaseMark/casedev-python#accessing-raw-response-data-eg-headers
        """
        return AsyncTemplatesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTemplatesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/CaseMark/casedev-python#with_streaming_response
        """
        return AsyncTemplatesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        content: str,
        name: str,
        type: Literal["caption", "signature", "letterhead", "certificate", "footer", "custom"],
        description: str | Omit = omit,
        styles: object | Omit = omit,
        tags: SequenceNotStr[str] | Omit = omit,
        variables: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateCreateResponse:
        """Create a new format template for document formatting.

        Templates support
        variables using `{{variable}}` syntax and can be used for captions, signatures,
        letterheads, certificates, footers, or custom formatting needs.

        Args:
          content: Template content with {{variable}} placeholders

          name: Template name

          type: Template type

          description: Template description

          styles: CSS styles for the template

          tags: Template tags for organization

          variables: Template variables (auto-detected if not provided)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/format/v1/templates",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "name": name,
                    "type": type,
                    "description": description,
                    "styles": styles,
                    "tags": tags,
                    "variables": variables,
                },
                template_create_params.TemplateCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateCreateResponse,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateRetrieveResponse:
        """Retrieve a specific document format template by ID.

        Format templates define how
        documents should be structured and formatted for specific legal use cases such
        as contracts, briefs, or pleadings.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._get(
            f"/format/v1/templates/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TemplateRetrieveResponse,
        )

    async def list(
        self,
        *,
        type: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> TemplateListResponse:
        """Retrieve all format templates for the organization.

        Templates define reusable
        document formatting patterns with customizable variables for consistent legal
        document generation.

        Filter by type to get specific template categories like contracts, pleadings, or
        correspondence.

        Args:
          type: Filter templates by type (e.g., contract, pleading, letter)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/format/v1/templates",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"type": type}, template_list_params.TemplateListParams),
            ),
            cast_to=TemplateListResponse,
        )


class TemplatesResourceWithRawResponse:
    def __init__(self, templates: TemplatesResource) -> None:
        self._templates = templates

        self.create = to_raw_response_wrapper(
            templates.create,
        )
        self.retrieve = to_raw_response_wrapper(
            templates.retrieve,
        )
        self.list = to_raw_response_wrapper(
            templates.list,
        )


class AsyncTemplatesResourceWithRawResponse:
    def __init__(self, templates: AsyncTemplatesResource) -> None:
        self._templates = templates

        self.create = async_to_raw_response_wrapper(
            templates.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            templates.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            templates.list,
        )


class TemplatesResourceWithStreamingResponse:
    def __init__(self, templates: TemplatesResource) -> None:
        self._templates = templates

        self.create = to_streamed_response_wrapper(
            templates.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            templates.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            templates.list,
        )


class AsyncTemplatesResourceWithStreamingResponse:
    def __init__(self, templates: AsyncTemplatesResource) -> None:
        self._templates = templates

        self.create = async_to_streamed_response_wrapper(
            templates.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            templates.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            templates.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["VaultDeleteResponse", "DeletedVault"]


class DeletedVault(BaseModel):
    id: Optional[str] = None

    bytes_freed: Optional[int] = FieldInfo(alias="bytesFreed", default=None)

    name: Optional[str] = None

    objects_deleted: Optional[int] = FieldInfo(alias="objectsDeleted", default=None)

    vectors_deleted: Optional[int] = FieldInfo(alias="vectorsDeleted", default=None)


class VaultDeleteResponse(BaseModel):
    deleted_vault: Optional[DeletedVault] = FieldInfo(alias="deletedVault", default=None)

    status: Optional[str] = None
    """Either 'deleted' or 'deletion_queued'"""

    success: Optional[bool] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1SimilarResponse", "Result"]


class Result(BaseModel):
    domain: Optional[str] = None

    published_date: Optional[str] = FieldInfo(alias="publishedDate", default=None)

    similarity_score: Optional[float] = FieldInfo(alias="similarityScore", default=None)

    snippet: Optional[str] = None

    text: Optional[str] = None

    title: Optional[str] = None

    url: Optional[str] = None


class V1SimilarResponse(BaseModel):
    processing_time: Optional[float] = FieldInfo(alias="processingTime", default=None)

    results: Optional[List[Result]] = None

    total_results: Optional[int] = FieldInfo(alias="totalResults", default=None)
